@@ -23,7 +23,6 @@ import cups
 import os
 import tempfile
 from base import *
-from base import _
 class ErrorLogCheckpoint(Question):
     def __init__ (self, troubleshooter):
         Question.__init__ (self, troubleshooter, "Error log checkpoint")
@@ -46,6 +45,22 @@ class ErrorLogCheckpoint(Question):
         troubleshooter.new_page (page, self)
         self.persistent_answers = {}
 
+    def __del__ (self):
+        if not self.persistent_answers.get ('error_log_debug_logging_set',
+                                            False):
+            return
+
+        c = self.troubleshooter.answers['_authenticated_connection']
+        settings = c.adminGetServerSettings ()
+        if len (settings.keys ()) == 0:
+            return
+
+        settings[cups.CUPS_SERVER_DEBUG_LOGGING] = '0'
+        answers = self.troubleshooter.answers
+        orig_settings = self.persistent_answers['cups_server_settings']
+        settings['MaxLogSize'] = orig_settings.get ('MaxLogSize', '2000000')
+        c.adminSetServerSettings (settings)
+
     def display (self):
         self.answers = {}
         answers = self.troubleshooter.answers
@@ -65,12 +80,13 @@ class ErrorLogCheckpoint(Question):
         except cups.IPPError:
             settings = {}
 
+        self.forward_allowed = False
         self.label.set_text ('')
         if len (settings.keys ()) == 0:
             # Requires root
             return True
         else:
-            self.answers['cups_server_settings'] = settings
+            self.persistent_answers['cups_server_settings'] = settings
 
         try:
             if int (settings[cups.CUPS_SERVER_DEBUG_LOGGING]) != 0:
@@ -84,7 +100,8 @@ class ErrorLogCheckpoint(Question):
         return True
 
     def connect_signals (self, handler):
-        self.button_sigid = self.button.connect ('clicked', self.enable_clicked)
+        self.button_sigid = self.button.connect ('clicked', self.enable_clicked,
+                                                 handler)
 
     def disconnect_signals (self):
         self.button.disconnect (self.button_sigid)
@@ -113,14 +130,19 @@ class ErrorLogCheckpoint(Question):
         self.answers['error_log_checkpoint'] = statbuf[6]
         return self.answers
 
-    def enable_clicked (self, button):
+    def can_click_forward (self):
+        return self.forward_allowed
+
+    def enable_clicked (self, button, handler):
+        self.forward_allowed = True
+        handler (button)
         c = self.troubleshooter.answers['_authenticated_connection']
         try:
             settings = c.adminGetServerSettings ()
         except cups.IPPError:
             return
 
-        self.answers['cups_server_settings'] = settings.copy ()
+        self.persistent_answers['cups_server_settings'] = settings.copy ()
         MAXLOGSIZE='MaxLogSize'
         try:
             prev_debug = int (settings[cups.CUPS_SERVER_DEBUG_LOGGING])
